@@ -11,8 +11,20 @@ get_dataset_list = function(){
   link_dataflow = Sys.getenv("INSEE_sdmx_link_dataflow")
 
   df = get_insee(link_dataflow)
+
   if(!is.null(df)){
-    df = dplyr::filter(.data = df, !is.na(.data$Name.fr))
+    if("Name.fr" %in% names(df)){
+      df = dplyr::filter(.data = df, !is.na(.data$Name.fr))
+    }
+    # delete SERIES_BDM from dataset list
+
+    if ("id" %in% names(df)){
+      dataset_list = df$id
+
+      if("SERIES_BDM" %in% dataset_list){
+        df = df[-which(df$id == "SERIES_BDM"),]
+      }
+    }
   }
 
   # df = tibble::as_tibble(df)
