@@ -2,10 +2,9 @@
 read_dataset_metadata = function(dataset, dataset_metadata_file_cache){
 
   dir_creation_fail = try(create_insee_folder(), silent = TRUE)
+  insee_local_dir = file.path(rappdirs::user_data_dir(), "R", "insee", "insee")
 
-  if(!"try-error" %in% class(dir_creation_fail)){
-    insee_local_dir = file.path(rappdirs::user_data_dir(), "R", "insee", "insee")
-  }else{
+  if(("try-error" %in% class(dir_creation_fail))|(!file.exists(insee_local_dir))){
     insee_local_dir = tempdir()
   }
 
